netapp_ontap.models.container_volumes_flexcache API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.container_volumes_flexcache`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ContainerVolumesFlexcacheSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ContainerVolumesFlexcache object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `dr_cache: bool POST`

    If set to true, a DR cache is created.

  `origins: List[ContainerVolumeFlexcacheRelationship] POST`

    The origins field of the container_volumes_flexcache.

  `writeback: FlexcacheWriteback POST`

    The writeback field of the container_volumes_flexcache.